@@ -59,6 +59,25 @@ N_("[image:1]Peel and grate the potatoes. Peel and slice the onions. Mix with th
 N_("Put a frying pan on the hob at medium heat with a bit of oil.")
 N_("[image:2]Form thin patties in the pan and brown them on both sides.")
 N_("[image:0]Serve hot. Can be kept in a fridge and reheated in a micro-wave oven.")
+N_("Hazelnuts Butter")
+N_("Vegan Hazelnuts Butter that tastes like Nutella©, but better.")
+N_("Make the Hazelnuts Milk (see my Hazelnuts Milk recipe)")
+N_("Put the remaining paste in a bowl [image:0]")
+N_("(With Chocolate) Mix melted 75% vegan chocolate")
+N_("(With Cocoa Butter) Melt the cocoa butter [image:1]")
+N_("(With Cocoa Butter) Mix the hazelnuts milk, melted cocoa butter and the cocoa powder until the mass gets uniform [image:2]")
+N_("Enjoy [image:3]")
+N_("Hazelnuts Milk")
+N_("Simple Hazelnuts Milk with a smooth, naturally sweet flavor.")
+N_("Preheat the over at [temperature:200C]")
+N_("Place the hazelnuts in a tray [image:1]")
+N_("Leave the tray in the oven for 15 minutes [timer:00:15:00]")
+N_("Put water in the tray and peel the hazelnuts. Some will peel easily, while others will require manual peeling [image:2]")
+N_("Leave the hazelnuts underwater at least for 4 hours, or overnight")
+N_("Whisk the nuts and 1l of water with the blender until it gets thicker [image:3]")
+N_("Filter the resulting liquid with a nut milk sack (voal sack) [image:4]")
+N_("(Optional) You can make hazelnuts butter with the remaining paste (see my Hazelnuts Butter recipe) [image:5]")
+N_("Enjoy your milk [image:6]")
 N_("Kiwi-Mandarin Salsa")
 N_("This salad is a sweet and sour addition which work well to most main courses, for example lasagna. The juicy fruits inside makes it a very refreshing salad.")
 N_("[image:1]Wash the fruits and vegetables well.")
