@@ -166,7 +166,7 @@ populate_image_flowbox (GrEditPage *page)
 
         for (i = 0; i < images->len; i++) {
                 GrImage *ri = &g_array_index (images, GrImage, i);
-                g_autoptr(GdkPixbuf) pb = load_pixbuf_fill_size (ri->path, 0, 60, 40);
+                g_autoptr(GdkPixbuf) pb = load_pixbuf_fill_size (ri->path, 60, 40);
                 GtkWidget *image;
                 GtkWidget *child;
 
@@ -2139,7 +2139,6 @@ gr_edit_page_save (GrEditPage *page)
 
         if (ret) {
                 gr_image_viewer_persist_changes (GR_IMAGE_VIEWER (page->images));
-                gr_recipe_tile_recreate_css ();
 
                 return TRUE;
         }
