@@ -439,10 +439,6 @@ next:
         id = importer->recipe_ids[importer->current_recipe];
 
         if (id == NULL) {
-                // We're done!
-                gr_recipe_tile_recreate_css ();
-                gr_chef_tile_recreate_css ();
-
                 g_signal_emit (importer, done_signal, 0, importer->recipes);
                 cleanup_import (importer);
                 return TRUE;
@@ -673,7 +669,7 @@ show_chef_conflict_dialog (GrRecipeImporter *importer,
         gtk_text_buffer_set_text (buffer, gr_chef_get_description (chef), -1);
         if (gr_chef_get_image (chef) != NULL) {
                 g_autoptr(GdkPixbuf) pixbuf = NULL;
-                pixbuf = load_pixbuf_fit_size (gr_chef_get_image (chef), 0, 64, 64, TRUE);
+                pixbuf = load_pixbuf_fit_size (gr_chef_get_image (chef), 64, 64, TRUE);
                 gtk_image_set_from_pixbuf (GTK_IMAGE (old_chef_picture), pixbuf);
         }
 
@@ -689,7 +685,7 @@ show_chef_conflict_dialog (GrRecipeImporter *importer,
                 g_autoptr(GdkPixbuf) pixbuf = NULL;
                 g_autofree char *path = NULL;
                 path = g_build_filename (importer->dir, importer->chef_image_path, NULL);
-                pixbuf = load_pixbuf_fit_size (path, 0, 64, 64, TRUE);
+                pixbuf = load_pixbuf_fit_size (path, 64, 64, TRUE);
                 gtk_image_set_from_pixbuf (GTK_IMAGE (new_chef_picture), pixbuf);
         }
 
