@@ -144,8 +144,6 @@ gr_recipes_page_init (GrRecipesPage *page)
         populate_shopping_from_store (page);
         populate_categories_from_store (page);
         populate_chefs_from_store (page);
-        gr_recipe_tile_recreate_css ();
-        gr_chef_tile_recreate_css ();
         connect_store_signals (page);
 
         page->shopping_timeout = g_timeout_add_seconds (300, update_shopping_time, page);
@@ -328,13 +326,15 @@ populate_recipes_from_store (GrRecipesPage *self)
                 recipe = gr_recipe_store_get_recipe (store, keys[i]);
 
                 if (todays < 3 && gr_recipe_store_recipe_is_todays (store, recipe)) {
-                        tile = gr_recipe_tile_new (recipe);
-                        gtk_widget_show (tile);
                         if (todays == 0) {
+                                tile = gr_recipe_tile_new_wide (recipe);
+                                gtk_widget_show (tile);
                                 gtk_grid_attach (GTK_GRID (self->today_box), tile, 0, 0, 2, 1);
                                 todays += 2;
                         }
                         else {
+                                tile = gr_recipe_tile_new (recipe);
+                                gtk_widget_show (tile);
                                 gtk_grid_attach (GTK_GRID (self->today_box), tile, todays, 0, 1, 1);
                                 todays += 1;
                         }
@@ -418,8 +418,6 @@ populate_chefs_from_store (GrRecipesPage *self)
         int i;
         int count;
 
-        gr_chef_tile_recreate_css ();
-
         container_remove_all (GTK_CONTAINER (self->chefs_box));
 
         store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
